@@ -13,7 +13,7 @@ from flask_login import current_user, login_required
 from invenio_app_rdm.records_ui.views.deposits import deposit_create, deposit_edit
 from invenio_cache import current_cache
 from invenio_communities.proxies import current_communities
-from invenio_communities.views.communities import communities_new
+from invenio_communities.views.communities import VISIBILITY_FIELDS
 from invenio_rdm_records.proxies import current_rdm_records_service as rec_service
 from invenio_rdm_records.resources.serializers import UIJSONSerializer
 
@@ -44,6 +44,32 @@ def fetch_schemaorg_jsonld(doi_url):
     return metadata
 
 
+@login_required
+def communities_new():
+    """Override for the ``communities_new`` view function.
+
+    This is done because we use a ``LocalProxy`` for the ``SITE_UI_URL`` configuration
+    value instead of a string in order to make the URL generation flexible enough
+    to support multiple domain names.
+    However, ``json.dumps`` (used by default by the ``tojson`` filter) cannot handle
+    ``LocalProxy`` objects as values in dicts.
+    Thus, we need to dereference the value before passing it to the Jinja2 template
+    by converting the value to a string.
+
+    NOTE: Path for the overridden function from ``invenio-communities`` (v2.8.8):
+    ``invenio_communities.views.communities:communities_new``
+    """
+    # TODO this will probably need to be adjusted or removed according to how the
+    #      issue of multiple domain names will be addressed upstream
+    return render_template(
+        "invenio_communities/new.html",
+        form_config={
+            "access": {"visibility": VISIBILITY_FIELDS},
+            "SITE_UI_URL": str(current_app.config["SITE_UI_URL"]),
+        },
+    )
+
+
 @login_required
 def guarded_deposit_create(*args, **kwargs):
     """Guard the creation page for records, based on permissions."""
@@ -126,7 +152,8 @@ def create_blueprint(app):
         """Custom landing page showing the latest 5 records."""
         records = FrontpageRecordsSearch()[:5].sort("-created").execute()
         return render_template(
-            "invenio_theme_tuw/overrides/frontpage.html", records=_records_serializer(records)
+            "invenio_theme_tuw/overrides/frontpage.html",
+            records=_records_serializer(records),
         )
 
     def _records_serializer(records=None):
